%define common_summary A complete user-space boot splash system
%define embedded_common_summary a complete user-space boot splash system
%define common_description A boot splash program that doesn't require patching the Linux kernel. It paints\
graphic images directly to framebuffers using libdirectfb.
%define lib_major 1
%define lib_name %mklibname %{name} %{lib_major}
%define develname %mklibname %{name} -d

%define git_url git://git.debian.org/splashy/splashy.git

Summary:	%{common_summary}
Name:		splashy
Version:	0.3.13
Release:	%mkrel 7
License:	GPLv2+
Group:		System/Kernel and hardware
URL:		http://splashy.alioth.debian.org/wiki/
Source:		%{name}-%{version}.tar.gz
Source1:	splashy_find_files.in
# Werror breaks build when used with fortify (we could also empty the _fortify_cflags macro)
Patch0:		splashy-0.3.10-warnings.patch
# from upstream
Patch1:		splashy-0.3.13-waitchild.patch
# handle pid file in /dev/.splashy.pid, so that it can be managed in early boot when / is read-only
Patch2:		splashy-0.3.13-pid.patch
Patch3:		splashy-0.3.11-bootloader-config.patch
Patch4:		splashy-0.3.11-format_not_a_string_literal_and_no_format_arguments.diff
# (fc) 0.3.13-3mdv fix crash in repaint (GIT)
Patch5:		splashy-0.3.13-fixcrash.patch
# (hk) avoid boot freeze if splashy fails to init (eg. when fb isn't available)
Patch6:		splashy-0.3.13-avoid-freeze-without-fb.patch
BuildRequires:	libdirectfb-devel
BuildRequires:	glib2-devel
BuildRequires:	libmagic-static-devel
BuildRequires:	procps-devel
BuildRequires:	libpng-devel
BuildRequires:	libjpeg-devel
BuildRequires:	freetype2-static-devel
BuildRequires:	glibc-static-devel
BuildRequires:	png-static-devel
Requires:	bootsplash
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root

%description
%{common_description}

%package -n	%{lib_name}
Summary:	A library to %{embedded_common_summary}
Group:		System/Libraries

%description -n	%{lib_name}
%{common_description}

This package contains the library needed to run programs dynamically
linked with %{name}.

%package -n	%{develname}
Summary:	Development tools for programs using %{name}
Group:		Development/C
Requires:	%{lib_name} = %{version}
Provides:	%{name}-devel = %{version}-%{release}
Obsoletes:	%{mklibname %name 1 -d} <= 0.3.4

%description -n	%{develname}
%{common_description}

This package contains the header files and libraries needed for
developing programs using the %{name} library.

%prep
%setup -q
%patch0 -p1 -b .warnings
%patch1 -p1 -b .waitchild
%patch2 -p1 -b .pid
%patch3 -p1 -b .bootloader-config
%patch4 -p1 -b .format_not_a_string_literal_and_no_format_arguments
%patch5 -p1 -b .fixcrash
%patch6 -p1 -b .avoid-freeze-without-fb
NOCONFIGURE=1 ./autogen.sh

%build
%configure2_5x --prefix=/ --enable-static --datarootdir=%{_datadir}
%make -j1

%install
rm -rf %{buildroot}

export GCONF_DISABLE_MAKEFILE_SCHEMA_INSTALL="1"

%makeinstall_std

install -d %{buildroot}/sbin
mv %{buildroot}%{_sbindir}/* %{buildroot}/sbin

DFB_LIBDIR=$(pkg-config directfb-internal --variable=moduledir)
perl -pe "s,\@DFB_LIBDIR\@,$DFB_LIBDIR," %{SOURCE1} > %{buildroot}%{_sbindir}/splashy_find_files
chmod +x %{buildroot}%{_sbindir}/splashy_find_files

# remove Debian-specific files
rm -f %{buildroot}%{_sysconfdir}/lsb-base-logging.sh
rm -rf %{buildroot}%{_sysconfdir}/init.d
rm -rf %{buildroot}%{_datadir}/initramfs-tools

%find_lang %name

%clean
rm -rf %{buildroot}

%if %mdkversion < 200900
%post -n %{lib_name} -p /sbin/ldconfig
%endif
%if %mdkversion < 200900
%postun -n %{lib_name} -p /sbin/ldconfig
%endif

%triggerprein -- splashy < 0.3.10
if [ -d %{_sysconfdir}/%{name}/themes ] && [ ! -L %{_sysconfdir}/%{name}/themes ]; then
   mkdir -p %{_datadir}/%{name}
   mv %{_sysconfdir}/%{name}/themes %{_datadir}/%{name}
fi

%files -f %name.lang
%defattr(-, root, root)
%doc AUTHORS ChangeLog COPYING NEWS README TODO
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/default/*
%dir %{_sysconfdir}/splashy
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/splashy/*.xml
/sbin/*
%{_sysconfdir}/splashy/themes
%{_sbindir}/splashy_find_files
%{_sysconfdir}/console-tools/config.d/splashy
%dir %{_datadir}/splashy
%{_datadir}/splashy/*
%{_mandir}/man?/*

%files -n %{lib_name}
%defattr(-,root,root)
%{_libdir}/lib%{name}*.so.%{lib_major}*

%files -n %{develname}
%defattr(-,root,root)
%{_includedir}/%{name}*.h
%{_libdir}/lib%{name}*.la
%{_libdir}/lib%{name}*.so
%{_libdir}/lib%{name}*.a
%{_libdir}/pkgconfig/%name.pc


%changelog
* Tue Sep 22 2009 Olivier Blin <oblin@mandriva.com> 0.3.13-7mdv2010.0
+ Revision: 447421
- fix library summary (Titi sucks, thanks boklm for noticing it)

* Thu Sep 03 2009 Christophe Fergeau <cfergeau@mandriva.com> 0.3.13-6mdv2010.0
+ Revision: 427211
- rebuild

* Sat Apr 18 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 0.3.13-5mdv2009.1
+ Revision: 367953
- Fix boot hang issue when splash is enabled but frame buffer not
  available.

  + Thierry Vignaud <tvignaud@mandriva.com>
    - fix library summary

* Fri Mar 27 2009 Olivier Blin <oblin@mandriva.com> 0.3.13-4mdv2009.1
+ Revision: 361589
- make parent process wait for directfb init in child (patch from upstream), might help to solve resume issues (#44639)

* Wed Mar 25 2009 Frederic Crozat <fcrozat@mandriva.com> 0.3.13-3mdv2009.1
+ Revision: 361122
- Add git_url
- Patch5 (GIT): fix crash in repaint

* Wed Dec 31 2008 Oden Eriksson <oeriksson@mandriva.com> 0.3.13-2mdv2009.1
+ Revision: 321577
- set --datarootdir=%%{_datadir} to fix borkiness...

* Fri Dec 26 2008 Funda Wang <fundawang@mandriva.org> 0.3.13-1mdv2009.1
+ Revision: 319349
- New version 0.3.13

* Mon Dec 22 2008 Oden Eriksson <oeriksson@mandriva.com> 0.3.11-5mdv2009.1
+ Revision: 317587
- fix build with -Werror=format-security (P4)

* Wed Sep 03 2008 Olivier Blin <oblin@mandriva.com> 0.3.11-4mdv2009.0
+ Revision: 279864
- enable static libraries (for suspend)

* Wed Aug 27 2008 Olivier Blin <oblin@mandriva.com> 0.3.11-3mdv2009.0
+ Revision: 276562
- update splashy_config warning to suggest bootloader-config (#42328) and do not warn when called from make-bootsplash-raw
- move autogen back in prep section where it belongs
- remove old glib.la removal hack

* Sun Aug 17 2008 Funda Wang <fundawang@mandriva.org> 0.3.11-2mdv2009.0
+ Revision: 272977
- rebuild for new dfb

* Sun Jul 27 2008 Funda Wang <fundawang@mandriva.org> 0.3.11-1mdv2009.0
+ Revision: 250416
- clearify the file list
- New version 0.3.11
- drop patch1, merge upstream

* Thu Jul 24 2008 Olivier Blin <oblin@mandriva.com> 0.3.10-3mdv2009.0
+ Revision: 245527
- really apply pid patch (so that splashy removes /dev/.splashy.pid when stopped)

* Wed Jul 23 2008 Olivier Blin <oblin@mandriva.com> 0.3.10-2mdv2009.0
+ Revision: 243538
- remove unused initscript
- add a splashy_find_files helper that lists files to be included in initrd
- handle pid file in /dev/.splashy.pid, so that it can be managed in early boot when / is read-only
- remove directfb link patch (we don't build a static splashy anymore)
- require bootsplash (for /sbin/splash.sh and other helpers)
- fix upgrade from previous versions (by moving themes from /etc to /usr/share)

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

  + Funda Wang <fundawang@mandriva.org>
    - fix url

* Thu May 29 2008 Funda Wang <fundawang@mandriva.org> 0.3.10-1mdv2009.0
+ Revision: 213009
- rediff checkvideo patch
- New version 0.3.10

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tvignaud@mandriva.com>
    - kill re-definition of %%buildroot on Pixel's request

* Thu Aug 09 2007 Olivier Blin <oblin@mandriva.com> 0.3.5-2mdv2008.0
+ Revision: 60801
- remove bundled libglib-2.0.la
- 0.3.5

* Thu Jul 26 2007 Olivier Blin <oblin@mandriva.com> 0.3.4-3mdv2008.0
+ Revision: 55899
- new devel library policy
- fix warnings instead of removing Werror option

* Wed Jul 25 2007 Olivier Blin <oblin@mandriva.com> 0.3.4-2mdv2008.0
+ Revision: 55507
- buildrequires glibc and png static devel packages to get a full static build

* Sat Jul 21 2007 Olivier Blin <oblin@mandriva.com> 0.3.4-1mdv2008.0
+ Revision: 54319
- fix group
- 0.3.4
- specify fbdev as default directfb system and force linking with directfb system/wm/input libraries (making splashy work again!)
- fix segfault when video init fails

* Wed Jun 13 2007 Olivier Blin <oblin@mandriva.com> 0.3.3-1mdv2008.0
+ Revision: 38543
- drop post script (mxterm theme is not in the package anymore, and it should not be hardcoded anyway)
- 0.3.3
- build with static files from new directfb-devel
- add lib packages
- package console-tools hook and remove debian-specific files
- enable static linking
- do no build with Werror (breaks build with fortify)
- use the configure macro
- buildrequire freetype2-static-devel

  + Funda Wang <fundawang@mandriva.org>
    - New upstream version 0.3.2


* Sun Feb 25 2007 Oden Eriksson <oeriksson@mandriva.com> 0.1.8-2mdv2007.0
+ Revision: 125545
- fix build
- fix deps
- fix build and deps
- lib64 fixes
- Import splashy

* Fri Sep 29 2006 Oden Eriksson <oeriksson@mandriva.com> 0.1.8-1mdk
- initial Mandriva package (mille-xterm import)

